==> immutable-collection-encodings-1.4-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableSetEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableSetEncoding",
  imports = {
  },
  typeParams = {"T"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      code = "com.google.common.collect.ImmutableSet.of()",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"input: java.util.Collection<? extends T>"},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableSet().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableSet().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableSetEncoding<T>"},
      code = "{\nreturn this.@:getImmutableSet().equals(@^other.@:getImmutableSet())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@set != null) {\nreturn @@set;\n} else {\nreturn com.google.common.collect.ImmutableSet.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableSet",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getSet",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.Set<T>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollectionVarargs",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"elements: T..."},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_set",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet.Builder<T>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "add",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD",
      type = "void",
      typeParams = {},
      params = {"element: T..."},
      code = "{\nif (@@builder != null) {\n@@builder.add(@^element);\n} else if (@@set != null) {\n@@builder = com.google.common.collect.ImmutableSet.<@^T>builderWithExpectedSize(@@set.size() + 1)\n.addAll(@@set)\n.add(@^element);\n@@set = null;\n} else {\n@@builder = com.google.common.collect.ImmutableSet.builder();\n@@builder.add(@^element);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "addAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      code = "{\nif (@@builder != null) {\n@@builder.addAll(@^elements);\n} else if (@@set != null) {\nint additionalSize = 0;\nif (@^elements instanceof java.util.Collection) {\nadditionalSize = ((java.util.Collection<? extends @^T>) @^elements).size();\n}\n@@builder = com.google.common.collect.ImmutableSet.<@^T>builderWithExpectedSize(@@set.size() + additionalSize)\n.addAll(@@set)\n.addAll(@^elements);\n@@set = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableCollection) {\n@:set(@^elements);\n} else if (@^elements instanceof java.util.Collection) {\n@@builder = com.google.common.collect.ImmutableSet.builderWithExpectedSize(((java.util.Collection<? extends @^T>) @^elements).size());\n@@builder.addAll(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableSet.builder();\n@@builder.addAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.lang.Iterable<? extends T>"},
      code = "{\n@@set = com.google.common.collect.ImmutableSet.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableSetEncodingEnabled {}

==> immutable-collection-encodings-1.11.0-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableSetEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableSetEncoding",
  imports = {
  },
  typeParams = {"T"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"input: java.util.Collection<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableSet().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableSet().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableSetEncoding<T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn this.@:getImmutableSet().equals(@^other.@:getImmutableSet())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@set != null) {\nreturn @@set;\n} else {\nreturn com.google.common.collect.ImmutableSet.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "isSet",
      tags = {"BUILDER", "PRIVATE", "IS_INIT"},
      naming = "*_isSet",
      stdNaming = "NONE",
      type = "boolean",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @@set != null || @@builder != null;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableSet",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableSet.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getSet",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.Set<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableSet.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollectionVarargs",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"elements: T..."},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableSet.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_set",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableSet.Builder<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "add",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD",
      type = "void",
      typeParams = {},
      params = {"element: T..."},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.add(@^element);\n} else if (@@set != null) {\n@@builder =\ncom.google.common.collect.ImmutableSet\n.<@^T>builderWithExpectedSize(@@set.size() + 1)\n.addAll(@@set)\n.add(@^element);\n@@set = null;\n} else {\n@@builder = com.google.common.collect.ImmutableSet.builder();\n@@builder.add(@^element);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "addAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.addAll(@^elements);\n} else if (@@set != null) {\nint additionalSize = 0;\nif (@^elements instanceof java.util.Collection) {\nadditionalSize = ((java.util.Collection<? extends @^T>) @^elements).size();\n}\n@@builder =\ncom.google.common.collect.ImmutableSet\n.<@^T>builderWithExpectedSize(@@set.size() + additionalSize)\n.addAll(@@set)\n.addAll(@^elements);\n@@set = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableCollection) {\n@:set(@^elements);\n} else if (@^elements instanceof java.util.Collection) {\n@@builder =\ncom.google.common.collect.ImmutableSet.builderWithExpectedSize(\n((java.util.Collection<? extends @^T>) @^elements).size()\n);\n@@builder.addAll(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableSet.builder();\n@@builder.addAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\n@@set = com.google.common.collect.ImmutableSet.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableSetEncodingEnabled {}
